# Changelog

* *2.2.1* (2024-07-16)
  * Updated GitHub actions

* *2.2.0* (2024-07-15)
  * Dropped Python 3.8 support
  * Added multiple ruff linters

* *2.1.3* (2024-06-21)
  * Linted docs with `blacken-docs` via `ambient-package-update`

* *2.1.2* (2024-06-14)
  * Internal updates via `ambient-package-update`

* *2.1.1* (2024-05-31)
  * Changed log-level to "info" for successful dispatching
  * Improved configuration docs

* *2.1.0* (2024-05-27)
  * Added `ThreadEmailService` for simple async sending of emails
  * Added basic logging with privacy configuration to mail class
  * Restructured documentation
  * Restructured unit-tests
  * Minor test improvements

* *2.0.0* (2024-04-11)
  * Dropped Django 3.2 & 4.1 support (via `ambient-package-update`)
  * Internal updates via `ambient-package-update`

* *1.3.0** (2023-12-04)
  * Added Django 5.0 support

* *1.2.5** (2023-11-13)
  * Fixed wrong import path in docs

* *1.2.4** (2023-11-03)
  * Switched formatter from `black` to `ruff`

* *1.2.3** (2023-10-20)
  * Linter updaters including code adjustments
  * Updates from ambient updater

* *1.2.2** (2023-10-04)
  * Dependency to ambient updater updated

* *1.2.1** (2023-10-04)
  * Downgraded Python to 3.11 for readthedocs.org

* *1.2.0** (2023-10-04)
  * Added Python 3.12 support
  * Updated internal linter packages

* *1.1.6** (2023-09-08)
  * Metadata update via ambient package updater

* *1.1.5** (2023-09-08)
  * Metadata update via ambient package updater
  * Cleaned up test matrix

* **1.1.4** (2023-08-31)
  * Fixed downloads badge

* **1.1.3** (2023-08-31)
  * Improved type-hinting for constructor of `BaseEmailServiceFactory` and `BaseEmailService`

* **1.1.2** (2023-08-14)
  * Updated linters and add more strict linting rules

* **1.1.1** (2023-05-10)
  * Updated readme "maintenance" section
  * Updated package linters
  * Added release scripts for windows and UNIX

* **1.1.0** (2023-05-04)
  * Support for Django 4.2 added

* **1.0.2** (2023-05-04)
  * Updated documentation

* **1.0.1** (2023-05-03)
  * Added missing translations
  * Updated documentation

* **1.0.0** (2023-05-01)
  * Release as a separate package at PyPI (was before a part of [ai-django-core](https://pypi.org/project/ai-django-core/))
